@@ -943,8 +943,8 @@ class StaticConfiguration:
         """
         Returns (Nf,) array containing path current around each face.
         """
-        A, Asq_solver = self.get_circuit().get_cycle_matrix(), self.get_problem()._Asq_factorization()
-        return Asq_solver(A @ self.get_I())
+        A = self.get_circuit().get_cycle_matrix()
+        return self.get_circuit().Asq_solve(A @ self.get_I())
 
     def get_flux(self) -> np.ndarray:
         """
@@ -1071,20 +1071,37 @@ class StaticConfiguration:
         return self.get_error_kirchhoff_rules(), self.get_error_winding_rules()
 
     def plot(self, fig=None, node_quantity=None, junction_quantity="I", face_quantity=None,
-             vortex_quantity="n", show_grid=True, show_nodes=True, **kwargs):
+             vortex_quantity="n", show_grid=True, show_nodes=True, return_plot_handle=False,
+             **kwargs):
         """
         Visualize static configuration on circuit.
 
         See :py:attr:`circuit_visualize.CircuitPlot` for documentation.
+
+        Attributes
+        ----------
+        return_plot_handle=False : bool
+            If True this method returns the ConfigPlot object used to create the plot.
+
+        Returns
+        -------
+        fig : matplotlib figure handle
+            Returns figure handle
+        ax : matplotlib axis handle
+            Returns axis handle
+        plot_handle : ConfigPlot (optional)
+            Object used to create the plot
+
         """
         from pyjjasim.circuit_visualize import ConfigPlot
 
         self.plot_handle = ConfigPlot(self, vortex_quantity=vortex_quantity, show_grid=show_grid,
                                       junction_quantity=junction_quantity,  show_nodes=show_nodes,
                                       node_quantity=node_quantity, face_quantity=face_quantity,
-                                      fig=fig, **kwargs).make()
-
-        return self.plot_handle
+                                      fig=fig, **kwargs)
+        if return_plot_handle:
+            return *self.plot_handle.make(), self.plot_handle
+        return self.plot_handle.make()
 
     def report(self):
         print("Kirchhoff rules error:    ", self.get_error_kirchhoff_rules())
@@ -1646,15 +1663,34 @@ def compute_stability(circuit: Circuit, theta, cp, maxiter=DEF_STAB_MAXITER,
         status, eigenvalue_list, residual_list = out
         return status
     if algorithm == 2:
-        eps = 2 * np.finfo(float).eps
-        f = scipy.sparse.linalg.splu(J, diag_pivot_thresh=0)
-        Up = (f.L @ scipy.sparse.diags(f.U.diagonal())).T
-        if not np.allclose((Up - f.U).data, 0):
-            print("warning: choleski factorization failed")
-            return 2
-        return int(~np.all(f.U.diagonal() < eps))
+        status = is_positive_definite_superlu(J)
+        if status == 2:
+            raise ValueError("Choleski factorization failed; unable to determine positive definiteness")
+        return status
     raise ValueError("invalid algorithm. Must be 0 (eigsh) or 1 (lobpcg) or 2 (choleski)")
 
+def is_positive_definite_superlu(X):
+    """
+    Determine if matrix is positive definite using superlu package.
+
+    Parameters
+    ----------
+    X : sparse matrix
+        Sparse matrix.
+
+    Returns
+    -------
+    status : int
+        0 -> positive definite, 1 -> not positive definite, 2 -> choleski factorization failed
+
+    """
+    eps = 2 * np.finfo(float).eps
+    f = scipy.sparse.linalg.splu(X, diag_pivot_thresh=0)
+    Up = (f.L @ scipy.sparse.diags(f.U.diagonal())).T
+    if not np.allclose((Up - f.U).data, 0):
+        return 2
+    return int(~np.all(f.U.diagonal() < eps))
+
 def stability_get_preconditioner(circuit: Circuit, cp, scheme):
     """
     Compute preconditioner to determine stability
